@@ -61,6 +61,7 @@ class DeeplTranslator(Translator):
 
         logging.info(f"Going to {self.url}")
         self.driver.get(self.url)
+        self._closePopUp()
 
         self.input_lang_from = TextArea(
             self.driver, "CLASS_NAME", "lmt__source_textarea"
@@ -69,6 +70,15 @@ class DeeplTranslator(Translator):
             self.driver, "CLASS_NAME", "lmt__target_textarea"
         )
 
+    def _closePopUp(self):
+        Button(
+            self.driver,
+            "CSS_SELECTOR",
+            "[aria-label=Close]",
+            wait_time=10,
+            optional=True,
+        ).click()
+
     def _set_source_language(self, language: str) -> None:
         self._set_language(language, "lmt__language_select--source")
 
